'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var core = require('@vue-storefront/core');
var gql = require('graphql-tag');
var fetch$1 = require('isomorphic-fetch');
var SdkAuth = require('@commercetools/sdk-auth');
var ApolloClient = require('apollo-client');
var apolloCacheInmemory = require('apollo-cache-inmemory');
var apolloLinkError = require('apollo-link-error');
var apolloLinkRetry = require('apollo-link-retry');
var apolloLinkContext = require('apollo-link-context');
var apolloLinkHttp = require('apollo-link-http');
var utilities = require('@apollo/client/utilities');
var apolloLink = require('apollo-link');

function _interopDefaultLegacy (e) { return e && typeof e === 'object' && 'default' in e ? e : { 'default': e }; }

var gql__default = /*#__PURE__*/_interopDefaultLegacy(gql);
var fetch__default = /*#__PURE__*/_interopDefaultLegacy(fetch$1);
var SdkAuth__default = /*#__PURE__*/_interopDefaultLegacy(SdkAuth);
var ApolloClient__default = /*#__PURE__*/_interopDefaultLegacy(ApolloClient);

/*! *****************************************************************************
Copyright (c) Microsoft Corporation.

Permission to use, copy, modify, and/or distribute this software for any
purpose with or without fee is hereby granted.

THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES WITH
REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF MERCHANTABILITY
AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY SPECIAL, DIRECT,
INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES WHATSOEVER RESULTING FROM
LOSS OF USE, DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR
OTHER TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
PERFORMANCE OF THIS SOFTWARE.
***************************************************************************** */

var __assign = function() {
    __assign = Object.assign || function __assign(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p)) t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};

function __awaiter(thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
}

function __generator(thisArg, body) {
    var _ = { label: 0, sent: function() { if (t[0] & 1) throw t[1]; return t[1]; }, trys: [], ops: [] }, f, y, t, g;
    return g = { next: verb(0), "throw": verb(1), "return": verb(2) }, typeof Symbol === "function" && (g[Symbol.iterator] = function() { return this; }), g;
    function verb(n) { return function (v) { return step([n, v]); }; }
    function step(op) {
        if (f) throw new TypeError("Generator is already executing.");
        while (_) try {
            if (f = 1, y && (t = op[0] & 2 ? y["return"] : op[0] ? y["throw"] || ((t = y["return"]) && t.call(y), 0) : y.next) && !(t = t.call(y, op[1])).done) return t;
            if (y = 0, t) op = [op[0] & 2, t.value];
            switch (op[0]) {
                case 0: case 1: t = op; break;
                case 4: _.label++; return { value: op[1], done: false };
                case 5: _.label++; y = op[1]; op = [0]; continue;
                case 7: op = _.ops.pop(); _.trys.pop(); continue;
                default:
                    if (!(t = _.trys, t = t.length > 0 && t[t.length - 1]) && (op[0] === 6 || op[0] === 2)) { _ = 0; continue; }
                    if (op[0] === 3 && (!t || (op[1] > t[0] && op[1] < t[3]))) { _.label = op[1]; break; }
                    if (op[0] === 6 && _.label < t[1]) { _.label = t[1]; t = op; break; }
                    if (t && _.label < t[2]) { _.label = t[2]; _.ops.push(op); break; }
                    if (t[2]) _.ops.pop();
                    _.trys.pop(); continue;
            }
            op = body.call(thisArg, _);
        } catch (e) { op = [6, e]; y = 0; } finally { f = t = 0; }
        if (op[0] & 5) throw op[1]; return { value: op[0] ? op[1] : void 0, done: true };
    }
}

function __spreadArray(to, from, pack) {
    if (pack || arguments.length === 2) for (var i = 0, l = from.length, ar; i < l; i++) {
        if (ar || !(i in from)) {
            if (!ar) ar = Array.prototype.slice.call(from, 0, i);
            ar[i] = from[i];
        }
    }
    return to.concat(ar || Array.prototype.slice.call(from));
}

function __makeTemplateObject(cooked, raw) {
    if (Object.defineProperty) { Object.defineProperty(cooked, "raw", { value: raw }); } else { cooked.raw = raw; }
    return cooked;
}

var AddressFragment = "\n  fragment DefaultAddress on Address {\n    id\n    title\n    firstName\n    lastName\n    streetName\n    streetNumber\n    postalCode\n    city\n    country\n    state\n    region\n    company\n    apartment\n    phone\n    mobile\n  }\n";

// TODO: Remove all address information and update PRO packages to use customQueries when this is implemented: https://github.com/DivanteLtd/vue-storefront/issues/5049
var CustomerFragment = "\n  " + AddressFragment + "\n\n  fragment DefaultCustomer on Customer {\n    version\n    firstName\n    lastName\n    email\n    addresses {\n      id\n    }\n    shippingAddresses {\n      ...DefaultAddress\n    }\n    billingAddresses {\n      ...DefaultAddress\n    }\n    defaultBillingAddressId\n    defaultShippingAddressId\n  }\n";

var ProductPriceFragment = "\n  fragment DefaultProductPrice on ProductPrice {\n    discounted {\n      value {\n        type\n        currencyCode\n        centAmount\n        fractionDigits\n      }\n      discount {\n        validFrom\n        validUntil\n        isActive\n        name(acceptLanguage: $acceptLanguage)\n      }\n    }\n    value {\n      type\n      currencyCode\n      centAmount\n      fractionDigits\n    }\n  }\n";

var LineItemFragment = "\n  " + ProductPriceFragment + "\n\n  fragment DefaultLineItem on LineItem {\n    id\n    productId\n    name(acceptLanguage: $acceptLanguage)\n    productSlug(acceptLanguage: $acceptLanguage)\n    quantity\n    discountedPricePerQuantity {\n      quantity\n      discountedPrice {\n        value {\n          centAmount\n        }\n        includedDiscounts {\n          discount {\n            name(acceptLanguage: $acceptLanguage)\n            isActive\n          }\n        }\n      }\n    }\n    variant {\n      id\n      sku\n      price(currency: $currency) {\n        tiers {\n          value {\n            centAmount\n          }\n        }\n        value {\n          centAmount\n        }\n        discounted {\n          value {\n            centAmount\n          }\n          discount {\n            isActive\n            name(acceptLanguage: $acceptLanguage)\n          }\n        }\n      }\n      images {\n        url\n        label\n      }\n      attributesRaw {\n        name\n        value\n        attributeDefinition {\n          type {\n            name\n          }\n          label(locale: $locale)\n        }\n      }\n    }\n    price {\n      ...DefaultProductPrice\n    }\n  }\n";

var ShippingMethodFragment = "\n  fragment DefaultShippingMethod on ShippingMethod {\n    id\n    version\n    name\n    isDefault\n    localizedDescription(acceptLanguage: $acceptLanguage)\n    zoneRates {\n      zone {\n        id\n        name\n      }\n      shippingRates {\n        freeAbove {\n          type\n          centAmount\n        }\n        isMatching\n        price {\n          centAmount\n        }\n      }\n    }\n  }\n";

var CartFragment = "\n  " + AddressFragment + "\n  " + CustomerFragment + "\n  " + LineItemFragment + "\n  " + ShippingMethodFragment + "\n\n  fragment DefaultCart on Cart {\n    id\n    customerId\n    customerEmail\n    lineItems {\n      ...DefaultLineItem\n    }\n    totalPrice {\n      centAmount\n    }\n    shippingAddress {\n      ...DefaultAddress\n    }\n    billingAddress {\n      ...DefaultAddress\n    }\n    customer {\n      ...DefaultCustomer\n    }\n    totalPrice {\n      centAmount\n    }\n    taxedPrice {\n      totalNet {\n        centAmount\n      }\n      totalGross {\n        centAmount\n      }\n    }\n    paymentInfo {\n      payments {\n        id\n      }\n    }\n    shippingInfo {\n      price {\n        centAmount\n      }\n      shippingMethod {\n        ...DefaultShippingMethod\n      }\n    }\n    discountCodes {\n      discountCode {\n        id\n        code\n        isActive\n        validFrom\n        validUntil\n        name(acceptLanguage: $acceptLanguage)\n      }\n    }\n    refusedGifts {\n      isActive\n      validFrom\n      validUntil\n      name(acceptLanguage: $acceptLanguage)\n    }\n    custom {\n      customFieldsRaw {\n        name\n        value\n      }\n    }\n    cartState\n    version\n    inventoryMode\n  }\n";

var LocalizedStringFragment = "\n  fragment LocalizedStringFragment on LocalizedString {\n    value\n    locale\n  }\n";

var ChannelFragment = "\n  " + LocalizedStringFragment + "\n  " + AddressFragment + "\n\n  fragment ChannelFragment on Channel {\n    id\n    version\n    key\n    roles\n    name(locale: $locale)\n    description(locale: $locale)\n    nameAllLocales {\n      ...LocalizedStringFragment\n    }\n    descriptionAllLocales {\n      ...LocalizedStringFragment\n    }\n    address {\n      ...DefaultAddress\n    }\n  }\n";

var ReferenceFragment = "\n  fragment ReferenceFragment on Reference {\n    typeId\n    id\n  }\n";

var InitiatorFragment = "\n  " + ReferenceFragment + "\n\n  fragment InitiatorFragment on Initiator {\n    isPlatformClient\n    externalUserId\n    anonymousId\n    clientId\n    customerRef {\n      ...ReferenceFragment\n    }\n    userRef {\n      ...ReferenceFragment\n    }\n  }\n";

var OrderFragment = "\n  " + AddressFragment + "\n  " + LineItemFragment + "\n\n  fragment DefaultOrder on Order {\n    lineItems {\n      ...DefaultLineItem\n    }\n    totalPrice {\n      centAmount\n    }\n    orderState\n    id\n    orderNumber\n    version\n    createdAt\n    customerEmail\n    shipmentState\n    paymentState\n    shippingAddress {\n      ...DefaultAddress\n    }\n    billingAddress {\n      ...DefaultAddress\n    }\n    cart {\n      id\n      version\n    }\n  }\n";

var StoreFragment = "\n  " + LocalizedStringFragment + "\n  " + ChannelFragment + "\n  " + InitiatorFragment + "\n\n  fragment StoreFragment on Store {\n    id\n    version\n    key\n    languages\n    createdAt\n    lastModifiedAt\n    name (locale: $locale)\n    nameAllLocales {\n      ...LocalizedStringFragment\n    }\n    distributionChannels {\n      ...ChannelFragment\n    }\n    supplyChannels {\n      ...ChannelFragment\n    }\n    createdBy {\n      ...InitiatorFragment\n    }\n    lastModifiedBy {\n      ...InitiatorFragment\n    }\n  }\n";

var StoreQueryResultFragment = "\n  " + StoreFragment + "\n\n  fragment StoreQueryResultFragment on StoreQueryResult {\n    offset\n    count\n    total\n    results {\n      ...StoreFragment\n    }\n  }\n";

var defaultQuery$8 = gql__default["default"](templateObject_1$z || (templateObject_1$z = __makeTemplateObject(["\n  ", "\n\n  mutation updateCart(\n    $id: String!,\n    $version: Long!,\n    $actions: [MyCartUpdateAction!]!,\n    $locale: Locale!,\n    $acceptLanguage: [Locale!],\n    $currency: Currency!,\n    $storeKey: KeyReferenceInput\n  ) {\n    cart: updateMyCart(id: $id, version: $version, actions: $actions, storeKey: $storeKey) {\n      ...DefaultCart\n    }\n  }\n"], ["\n  ", "\n\n  mutation updateCart(\n    $id: String!,\n    $version: Long!,\n    $actions: [MyCartUpdateAction!]!,\n    $locale: Locale!,\n    $acceptLanguage: [Locale!],\n    $currency: Currency!,\n    $storeKey: KeyReferenceInput\n  ) {\n    cart: updateMyCart(id: $id, version: $version, actions: $actions, storeKey: $storeKey) {\n      ...DefaultCart\n    }\n  }\n"])), CartFragment);
var templateObject_1$z;

var isAnonymousSession = function (token) { var _a; return (_a = token === null || token === void 0 ? void 0 : token.scope) === null || _a === void 0 ? void 0 : _a.includes('anonymous_id'); };
var isUserSession = function (token) { var _a; return (_a = token === null || token === void 0 ? void 0 : token.scope) === null || _a === void 0 ? void 0 : _a.includes('customer_id'); };
var getStoreKey = function (store) { return store
    ? ({ storeKey: store === null || store === void 0 ? void 0 : store.split('/')[0] })
    : {}; };

var VERSION_MISMATCH_CODE = 'ConcurrentModification';
/**
 * @remarks References:
 * {@link UpdateCartParams}
 */
var updateCart = function (context, params, customQuery) { return __awaiter(void 0, void 0, void 0, function () {
    var _a, locale, acceptLanguage, currency, store, userVariables, defaultVariables, updateCartGql, error_1, canRetry, causedByMismatch, currentVersion;
    var _b, _c, _d, _e, _f, _g;
    return __generator(this, function (_h) {
        switch (_h.label) {
            case 0:
                _a = context.config, locale = _a.locale, acceptLanguage = _a.acceptLanguage, currency = _a.currency, store = _a.store;
                userVariables = params ? __assign({ locale: locale, currency: currency }, params) : {};
                defaultVariables = __assign(__assign(__assign({}, userVariables), { acceptLanguage: acceptLanguage }), getStoreKey(store));
                updateCartGql = context.extendQuery(customQuery, { updateCart: { query: defaultQuery$8, variables: defaultVariables } }).updateCart;
                _h.label = 1;
            case 1:
                _h.trys.push([1, 3, , 4]);
                return [4 /*yield*/, context.client.mutate({
                        mutation: gql__default["default"](templateObject_1$y || (templateObject_1$y = __makeTemplateObject(["", ""], ["", ""])), updateCartGql.query),
                        variables: updateCartGql.variables,
                        fetchPolicy: 'no-cache'
                    })];
            case 2: return [2 /*return*/, _h.sent()];
            case 3:
                error_1 = _h.sent();
                canRetry = (_b = params.versionFallback) !== null && _b !== void 0 ? _b : true;
                causedByMismatch = (_e = (_d = (_c = error_1.graphQLErrors) === null || _c === void 0 ? void 0 : _c[0]) === null || _d === void 0 ? void 0 : _d.code) === null || _e === void 0 ? void 0 : _e.includes(VERSION_MISMATCH_CODE);
                currentVersion = (_g = (_f = error_1.graphQLErrors) === null || _f === void 0 ? void 0 : _f[0]) === null || _g === void 0 ? void 0 : _g.currentVersion;
                if (!causedByMismatch || !canRetry || !currentVersion) {
                    throw error_1;
                }
                core.Logger.debug('Cart version mismatch. Retrying with current version.');
                return [2 /*return*/, updateCart(context, __assign(__assign({}, params), { version: currentVersion }), customQuery)];
            case 4: return [2 /*return*/];
        }
    });
}); };
var updateCart$1 = updateCart;
var templateObject_1$y;

var createAddLineItemAction = function (params) {
    return {
        addLineItem: __assign(__assign({ variantId: params.product.id, quantity: params.quantity, sku: params.product.sku }, (params.supplyChannel && { supplyChannel: { id: params.supplyChannel } })), (params.distributionChannel && { distributionChannel: { id: params.distributionChannel } }))
    };
};
var createRemoveLineItemAction = function (product) { return ({
    removeLineItem: {
        lineItemId: product.id,
        quantity: product.quantity
    }
}); };
var createChangeLineItemQuantityAction = function (product) { return ({
    changeLineItemQuantity: {
        lineItemId: product.id,
        quantity: product.quantity
    }
}); };
var setShippingAddressAction = function (shippingDetails) { return ({
    setShippingAddress: {
        address: {
            title: shippingDetails.title,
            salutation: shippingDetails.salutation,
            firstName: shippingDetails.firstName,
            lastName: shippingDetails.lastName,
            streetName: shippingDetails.streetName,
            streetNumber: shippingDetails.streetNumber,
            additionalStreetInfo: shippingDetails.additionalStreetInfo,
            postalCode: shippingDetails.postalCode,
            city: shippingDetails.city,
            region: shippingDetails.region,
            state: shippingDetails.state,
            country: shippingDetails.country,
            company: shippingDetails.company,
            department: shippingDetails.department,
            building: shippingDetails.building,
            apartment: shippingDetails.apartment,
            pOBox: shippingDetails.pOBox,
            phone: shippingDetails.phone,
            mobile: shippingDetails.mobile,
            email: shippingDetails.email,
            fax: shippingDetails.fax,
            additionalAddressInfo: shippingDetails.additionalAddressInfo
        }
    }
}); };
var addDiscountCodeAction = function (code) { return ({
    addDiscountCode: { code: code }
}); };
var removeDiscountCodeAction = function (discountCode) { return ({
    removeDiscountCode: { discountCode: discountCode }
}); };

/**
 * @remarks References:
 * {@link CartDetails}, {@link @vue-storefront/commercetools-api#ProductVariant}, {@link CartResponse}
 */
var addToCart = function (context, _a, params, customQuery) {
    var id = _a.id, version = _a.version;
    return __awaiter(void 0, void 0, void 0, function () {
        return __generator(this, function (_b) {
            switch (_b.label) {
                case 0: return [4 /*yield*/, updateCart$1(context, {
                        id: id,
                        version: version,
                        actions: [createAddLineItemAction(params)]
                    }, customQuery)];
                case 1: return [2 /*return*/, _b.sent()];
            }
        });
    });
};
var addToCart$1 = addToCart;

/**
 * @remarks References:
 * {@link CartDetails}, {@link CartResponse}
 */
var applyCartCoupon = function (settings, _a, discountCode, customQuery) {
    var id = _a.id, version = _a.version;
    return __awaiter(void 0, void 0, void 0, function () {
        return __generator(this, function (_b) {
            switch (_b.label) {
                case 0: return [4 /*yield*/, updateCart$1(settings, {
                        id: id,
                        version: version,
                        actions: [addDiscountCodeAction(discountCode)]
                    }, customQuery)];
                case 1: return [2 /*return*/, _b.sent()];
            }
        });
    });
};
var applyCartCoupon$1 = applyCartCoupon;

var defaultMutation$2 = gql__default["default"](templateObject_1$x || (templateObject_1$x = __makeTemplateObject(["\n  ", "\n\n  mutation createCart($draft: MyCartDraft!, $locale: Locale!, $acceptLanguage: [Locale!], $currency: Currency!, $storeKey: KeyReferenceInput) {\n    cart: createMyCart(draft: $draft, storeKey: $storeKey) {\n      ...DefaultCart\n    }\n  }\n"], ["\n  ", "\n\n  mutation createCart($draft: MyCartDraft!, $locale: Locale!, $acceptLanguage: [Locale!], $currency: Currency!, $storeKey: KeyReferenceInput) {\n    cart: createMyCart(draft: $draft, storeKey: $storeKey) {\n      ...DefaultCart\n    }\n  }\n"])), CartFragment);
var templateObject_1$x;

/**
 * @remarks References:
 * {@link CartData}
 */
var createCart = function (context, cartDraft, customQuery) {
    if (cartDraft === void 0) { cartDraft = {}; }
    return __awaiter(void 0, void 0, void 0, function () {
        var _a, locale, acceptLanguage, currency, country, store, inventoryMode, defaultVariables, createCartGql, request;
        return __generator(this, function (_b) {
            switch (_b.label) {
                case 0:
                    _a = context.config, locale = _a.locale, acceptLanguage = _a.acceptLanguage, currency = _a.currency, country = _a.country, store = _a.store, inventoryMode = _a.inventoryMode;
                    defaultVariables = __assign({ acceptLanguage: acceptLanguage, locale: locale, currency: currency, draft: __assign({ currency: currency, country: country, inventoryMode: inventoryMode }, cartDraft) }, getStoreKey(store));
                    createCartGql = context.extendQuery(customQuery, { createCart: { query: defaultMutation$2, variables: defaultVariables } }).createCart;
                    return [4 /*yield*/, context.client.mutate({
                            mutation: gql__default["default"](templateObject_1$w || (templateObject_1$w = __makeTemplateObject(["", ""], ["", ""])), createCartGql.query),
                            variables: createCartGql.variables,
                            fetchPolicy: 'no-cache'
                        })];
                case 1:
                    request = _b.sent();
                    return [2 /*return*/, request];
            }
        });
    });
};
var createCart$1 = createCart;
var templateObject_1$w;

var defaultMutation$1 = gql__default["default"](templateObject_1$v || (templateObject_1$v = __makeTemplateObject(["\n  ", "\n\n  mutation createMyOrderFromCart($draft: OrderMyCartCommand!, $locale: Locale!, $acceptLanguage: [Locale!], $currency: Currency!, $storeKey: KeyReferenceInput) {\n    order: createMyOrderFromCart(draft: $draft, storeKey: $storeKey) {\n      ...DefaultOrder\n    }\n  }\n"], ["\n  ", "\n\n  mutation createMyOrderFromCart($draft: OrderMyCartCommand!, $locale: Locale!, $acceptLanguage: [Locale!], $currency: Currency!, $storeKey: KeyReferenceInput) {\n    order: createMyOrderFromCart(draft: $draft, storeKey: $storeKey) {\n      ...DefaultOrder\n    }\n  }\n"])), OrderFragment);
var templateObject_1$v;

/**
 * @remarks References:
 * {@link OrderMyCartCommand}, {@link OrderMutationResponse}
 */
var createMyOrderFromCart = function (context, draft, customQuery) { return __awaiter(void 0, void 0, void 0, function () {
    var _a, locale, acceptLanguage, currency, store, defaultVariables, createMyOrderFromCart;
    return __generator(this, function (_b) {
        switch (_b.label) {
            case 0:
                _a = context.config, locale = _a.locale, acceptLanguage = _a.acceptLanguage, currency = _a.currency, store = _a.store;
                defaultVariables = __assign({ locale: locale, acceptLanguage: acceptLanguage, currency: currency, draft: draft }, getStoreKey(store));
                createMyOrderFromCart = context.extendQuery(customQuery, { createMyOrderFromCart: { query: defaultMutation$1, variables: defaultVariables } }).createMyOrderFromCart;
                return [4 /*yield*/, context.client.mutate({
                        mutation: gql__default["default"](templateObject_1$u || (templateObject_1$u = __makeTemplateObject(["", ""], ["", ""])), createMyOrderFromCart.query),
                        variables: createMyOrderFromCart.variables,
                        fetchPolicy: 'no-cache'
                    })];
            case 1: return [2 /*return*/, _b.sent()];
        }
    });
}); };
var createMyOrderFromCart$1 = createMyOrderFromCart;
var templateObject_1$u;

var CustomerChangeMyPassword = gql__default["default"](templateObject_1$t || (templateObject_1$t = __makeTemplateObject(["\n  ", "\n\n  mutation customerChangeMyPassword($version: Long!, $currentPassword: String!, $newPassword: String!, $storeKey: KeyReferenceInput) {\n    user: customerChangeMyPassword(version: $version, currentPassword: $currentPassword, newPassword: $newPassword, storeKey: $storeKey) {\n      ...DefaultCustomer\n    }\n  }\n"], ["\n  ", "\n\n  mutation customerChangeMyPassword($version: Long!, $currentPassword: String!, $newPassword: String!, $storeKey: KeyReferenceInput) {\n    user: customerChangeMyPassword(version: $version, currentPassword: $currentPassword, newPassword: $newPassword, storeKey: $storeKey) {\n      ...DefaultCustomer\n    }\n  }\n"])), CustomerFragment);
var templateObject_1$t;

/**
 * @remarks References:
 * {@link ChangeMyPasswordResponse}
 */
var customerChangeMyPassword = function (_a, version, currentPassword, newPassword) {
    var client = _a.client;
    return __awaiter(void 0, void 0, void 0, function () {
        return __generator(this, function (_b) {
            switch (_b.label) {
                case 0: return [4 /*yield*/, client.mutate({
                        mutation: gql__default["default"](templateObject_1$s || (templateObject_1$s = __makeTemplateObject(["", ""], ["", ""])), CustomerChangeMyPassword),
                        variables: {
                            version: version,
                            currentPassword: currentPassword,
                            newPassword: newPassword
                        },
                        fetchPolicy: 'no-cache'
                    })];
                case 1: return [2 /*return*/, _b.sent()];
            }
        });
    });
};
var customerChangeMyPassword$1 = customerChangeMyPassword;
var templateObject_1$s;

var CustomerSignMeInMutation = gql__default["default"](templateObject_1$r || (templateObject_1$r = __makeTemplateObject(["\n  ", "\n  ", "\n\n  mutation customerSignMeIn($draft: CustomerSignMeInDraft!, $locale: Locale!, $acceptLanguage: [Locale!], $currency: Currency!, $storeKey: KeyReferenceInput) {\n    user: customerSignMeIn(draft: $draft, storeKey: $storeKey) {\n      customer {\n        ...DefaultCustomer\n      }\n      cart {\n        ...DefaultCart\n      }\n    }\n  }\n"], ["\n  ", "\n  ", "\n\n  mutation customerSignMeIn($draft: CustomerSignMeInDraft!, $locale: Locale!, $acceptLanguage: [Locale!], $currency: Currency!, $storeKey: KeyReferenceInput) {\n    user: customerSignMeIn(draft: $draft, storeKey: $storeKey) {\n      customer {\n        ...DefaultCustomer\n      }\n      cart {\n        ...DefaultCart\n      }\n    }\n  }\n"])), CustomerFragment, CartFragment);
var templateObject_1$r;

/**
 * @remarks References:
 * {@link CustomerSignMeInDraft}, {@link SignInResponse}
 */
var customerSignMeIn = function (context, draft) { return __awaiter(void 0, void 0, void 0, function () {
    var _a, locale, acceptLanguage, currency, loginResponse;
    return __generator(this, function (_b) {
        switch (_b.label) {
            case 0:
                _a = context.config, locale = _a.locale, acceptLanguage = _a.acceptLanguage, currency = _a.currency;
                return [4 /*yield*/, context.client.mutate({
                        mutation: gql__default["default"](templateObject_1$q || (templateObject_1$q = __makeTemplateObject(["", ""], ["", ""])), CustomerSignMeInMutation),
                        variables: {
                            draft: draft,
                            locale: locale,
                            acceptLanguage: acceptLanguage,
                            currency: currency
                        },
                        fetchPolicy: 'no-cache'
                    })];
            case 1:
                loginResponse = _b.sent();
                return [2 /*return*/, loginResponse];
        }
    });
}); };
var customerSignMeIn$1 = customerSignMeIn;
var templateObject_1$q;

var CustomerSignMeUpMutation = gql__default["default"](templateObject_1$p || (templateObject_1$p = __makeTemplateObject(["\n  ", "\n  ", "\n\n  mutation customerSignMeUp($draft: CustomerSignMeUpDraft!, $locale: Locale!, $acceptLanguage: [Locale!], $currency: Currency!, $storeKey: KeyReferenceInput) {\n    user: customerSignMeUp(draft: $draft, storeKey: $storeKey) {\n      customer {\n        ...DefaultCustomer\n      }\n      cart {\n        ...DefaultCart\n      }\n    }\n  }\n"], ["\n  ", "\n  ", "\n\n  mutation customerSignMeUp($draft: CustomerSignMeUpDraft!, $locale: Locale!, $acceptLanguage: [Locale!], $currency: Currency!, $storeKey: KeyReferenceInput) {\n    user: customerSignMeUp(draft: $draft, storeKey: $storeKey) {\n      customer {\n        ...DefaultCustomer\n      }\n      cart {\n        ...DefaultCart\n      }\n    }\n  }\n"])), CustomerFragment, CartFragment);
var templateObject_1$p;

/**
 * @remarks References:
 * {@link CustomerSignMeUpDraft}, {@link SignInResponse}
 */
var customerSignMeUp = function (context, draft) { return __awaiter(void 0, void 0, void 0, function () {
    var _a, locale, acceptLanguage, currency;
    return __generator(this, function (_b) {
        switch (_b.label) {
            case 0:
                _a = context.config, locale = _a.locale, acceptLanguage = _a.acceptLanguage, currency = _a.currency;
                return [4 /*yield*/, context.client.mutate({
                        mutation: gql__default["default"](templateObject_1$o || (templateObject_1$o = __makeTemplateObject(["", ""], ["", ""])), CustomerSignMeUpMutation),
                        variables: {
                            draft: draft,
                            locale: locale,
                            acceptLanguage: acceptLanguage,
                            currency: currency
                        },
                        fetchPolicy: 'no-cache'
                    })];
            case 1: return [2 /*return*/, _b.sent()];
        }
    });
}); };
var customerSignMeUp$1 = customerSignMeUp;
var templateObject_1$o;

var customerSignOut = function (_a) {
    var config = _a.config;
    return __awaiter(void 0, void 0, void 0, function () {
        var _b, _c;
        return __generator(this, function (_d) {
            (_c = (_b = config.auth).onTokenRemove) === null || _c === void 0 ? void 0 : _c.call(_b);
            return [2 /*return*/];
        });
    });
};
var customerSignOut$1 = customerSignOut;

var changeCustomerEmailAction = function (email) { return ({
    changeEmail: { email: email }
}); };
var setCustomerFirstNameAction = function (firstName) { return ({
    setFirstName: { firstName: firstName }
}); };
var setCustomerLastNameAction = function (lastName) { return ({
    setLastName: { lastName: lastName }
}); };

var CustomerUpdateMeMutation = gql__default["default"](templateObject_1$n || (templateObject_1$n = __makeTemplateObject(["\n  ", "\n\n  mutation customerUpdateMe($version: Long!, $actions: [MyCustomerUpdateAction!]!, $storeKey: KeyReferenceInput) {\n    user: updateMyCustomer(version: $version, actions: $actions, storeKey: $storeKey) {\n      ...DefaultCustomer\n    }\n  }\n"], ["\n  ", "\n\n  mutation customerUpdateMe($version: Long!, $actions: [MyCustomerUpdateAction!]!, $storeKey: KeyReferenceInput) {\n    user: updateMyCustomer(version: $version, actions: $actions, storeKey: $storeKey) {\n      ...DefaultCustomer\n    }\n  }\n"])), CustomerFragment);
var templateObject_1$n;

var customerUpdateMe = function (_a, currentUser, updatedUserData) {
    var client = _a.client;
    return __awaiter(void 0, void 0, void 0, function () {
        var updateResponse;
        return __generator(this, function (_b) {
            switch (_b.label) {
                case 0: return [4 /*yield*/, client.mutate({
                        mutation: gql__default["default"](templateObject_1$m || (templateObject_1$m = __makeTemplateObject(["", ""], ["", ""])), CustomerUpdateMeMutation),
                        variables: {
                            version: currentUser.version,
                            actions: [
                                changeCustomerEmailAction(updatedUserData.email),
                                setCustomerFirstNameAction(updatedUserData.firstName),
                                setCustomerLastNameAction(updatedUserData.lastName)
                            ]
                        },
                        fetchPolicy: 'no-cache'
                    })];
                case 1:
                    updateResponse = _b.sent();
                    return [2 /*return*/, updateResponse.data];
            }
        });
    });
};
var customerUpdateMe$1 = customerUpdateMe;
var templateObject_1$m;

var defaultMutation = gql__default["default"](templateObject_1$l || (templateObject_1$l = __makeTemplateObject(["\n    ", "\n\n    mutation deleteCart($id: String!, $version: Long!, $locale: Locale!, $acceptLanguage: [Locale!], $currency: Currency!) {\n        cart: deleteMyCart(id: $id, version: $version) {\n            ...DefaultCart\n        }\n    }\n"], ["\n    ", "\n\n    mutation deleteCart($id: String!, $version: Long!, $locale: Locale!, $acceptLanguage: [Locale!], $currency: Currency!) {\n        cart: deleteMyCart(id: $id, version: $version) {\n            ...DefaultCart\n        }\n    }\n"])), CartFragment);
var templateObject_1$l;

/**
 * @remarks References:
 * {@link CartDetails}
 */
var deleteCart = function (context, _a, customQuery) {
    var id = _a.id, version = _a.version;
    return __awaiter(void 0, void 0, void 0, function () {
        var _b, locale, acceptLanguage, currency, defaultVariables, deleteCartGql;
        return __generator(this, function (_c) {
            switch (_c.label) {
                case 0:
                    _b = context.config, locale = _b.locale, acceptLanguage = _b.acceptLanguage, currency = _b.currency;
                    defaultVariables = {
                        id: id,
                        version: version,
                        acceptLanguage: acceptLanguage,
                        locale: locale,
                        currency: currency
                    };
                    deleteCartGql = context.extendQuery(customQuery, { deleteCart: { query: defaultMutation, variables: defaultVariables } }).deleteCart;
                    return [4 /*yield*/, context.client.mutate({
                            mutation: gql__default["default"](templateObject_1$k || (templateObject_1$k = __makeTemplateObject(["", ""], ["", ""])), deleteCartGql.query),
                            variables: deleteCartGql.variables,
                            fetchPolicy: 'no-cache'
                        })];
                case 1: return [2 /*return*/, _c.sent()];
            }
        });
    });
};
var deleteCart$1 = deleteCart;
var templateObject_1$k;

var defaultQuery$7 = gql__default["default"](templateObject_1$j || (templateObject_1$j = __makeTemplateObject(["\n  ", "\n\n  query getCart($cartId: String!, $locale: Locale!, $acceptLanguage: [Locale!], $currency: Currency!) {\n    cart(id: $cartId) {\n      ...DefaultCart\n    }\n  }\n"], ["\n  ", "\n\n  query getCart($cartId: String!, $locale: Locale!, $acceptLanguage: [Locale!], $currency: Currency!) {\n    cart(id: $cartId) {\n      ...DefaultCart\n    }\n  }\n"])), CartFragment);
var templateObject_1$j;

/**
 * @remarks References:
 * {@link CartQueryResponse}
 */
var getCart = function (_a, cartId) {
    var config = _a.config, client = _a.client;
    return __awaiter(void 0, void 0, void 0, function () {
        var locale, acceptLanguage, currency;
        return __generator(this, function (_b) {
            switch (_b.label) {
                case 0:
                    locale = config.locale, acceptLanguage = config.acceptLanguage, currency = config.currency;
                    return [4 /*yield*/, client.query({
                            query: gql__default["default"](templateObject_1$i || (templateObject_1$i = __makeTemplateObject(["", ""], ["", ""])), defaultQuery$7),
                            variables: {
                                cartId: cartId,
                                locale: locale,
                                acceptLanguage: acceptLanguage,
                                currency: currency
                            },
                            fetchPolicy: 'no-cache'
                        })];
                case 1: return [2 /*return*/, _b.sent()];
            }
        });
    });
};
var getCart$1 = getCart;
var templateObject_1$i;

var defaultQuery$6 = gql__default["default"](templateObject_1$h || (templateObject_1$h = __makeTemplateObject(["\n  fragment Children on Category {\n    id\n    slug(acceptLanguage: $acceptLanguage)\n    name(acceptLanguage: $acceptLanguage)\n    childCount\n  }\n\n  fragment DefaultCategory on Category {\n    id\n    slug(acceptLanguage: $acceptLanguage)\n    name(acceptLanguage: $acceptLanguage)\n    childCount\n    children {\n      ...Children\n      children {\n        ...Children\n        children {\n          ...Children\n        }\n      }\n    }\n  }\n\n  query categories($where: String, $sort: [String!], $limit: Int, $offset: Int, $acceptLanguage: [Locale!]) {\n    categories(where: $where, sort: $sort, limit: $limit, offset: $offset) {\n      offset\n      count\n      total\n      results {\n        id\n        slug(acceptLanguage: $acceptLanguage)\n        name(acceptLanguage: $acceptLanguage)\n        description(acceptLanguage: $acceptLanguage)\n        childCount\n        parent {\n          ...DefaultCategory\n          parent {\n            ...DefaultCategory\n            parent {\n              ...DefaultCategory\n            }\n          }\n        }\n        children {\n          ...DefaultCategory\n        }\n      }\n    }\n  }\n"], ["\n  fragment Children on Category {\n    id\n    slug(acceptLanguage: $acceptLanguage)\n    name(acceptLanguage: $acceptLanguage)\n    childCount\n  }\n\n  fragment DefaultCategory on Category {\n    id\n    slug(acceptLanguage: $acceptLanguage)\n    name(acceptLanguage: $acceptLanguage)\n    childCount\n    children {\n      ...Children\n      children {\n        ...Children\n        children {\n          ...Children\n        }\n      }\n    }\n  }\n\n  query categories($where: String, $sort: [String!], $limit: Int, $offset: Int, $acceptLanguage: [Locale!]) {\n    categories(where: $where, sort: $sort, limit: $limit, offset: $offset) {\n      offset\n      count\n      total\n      results {\n        id\n        slug(acceptLanguage: $acceptLanguage)\n        name(acceptLanguage: $acceptLanguage)\n        description(acceptLanguage: $acceptLanguage)\n        childCount\n        parent {\n          ...DefaultCategory\n          parent {\n            ...DefaultCategory\n            parent {\n              ...DefaultCategory\n            }\n          }\n        }\n        children {\n          ...DefaultCategory\n        }\n      }\n    }\n  }\n"])));
var templateObject_1$h;

var AttributeType;
(function (AttributeType) {
    AttributeType["STRING"] = "StringAttribute";
    AttributeType["DATE"] = "DateAttribute";
    AttributeType["DATETIME"] = "DateTimeAttribute";
    AttributeType["TIME"] = "TimeAttribute";
    AttributeType["NUMBER"] = "NumberAttribute";
    AttributeType["ENUM"] = "EnumAttribute";
    AttributeType["LOCALIZED_ENUM"] = "LocalizedEnumAttribute";
    AttributeType["LOCALIZED_STRING"] = "LocalizedStringAttribute";
    AttributeType["MONEY"] = "MoneyAttribute";
    AttributeType["BOOLEAN"] = "BooleanAttribute";
})(AttributeType || (AttributeType = {}));

var mapFilterToPredicate = function (settings, filter) {
    var locale = settings.locale, currency = settings.currency;
    var valuePredicate;
    switch (filter.type) {
        case AttributeType.STRING:
            valuePredicate = "value = \"" + filter.value + "\"";
            break;
        case AttributeType.DATE:
        case AttributeType.DATETIME:
        case AttributeType.TIME:
            valuePredicate = Array.isArray(filter.value) ? "value >= \"" + filter.value[0] + "\" and value <= \"" + filter.value[1] + "\"" : "value = \"" + filter.value + "\"";
            break;
        case AttributeType.NUMBER:
            valuePredicate = Array.isArray(filter.value) ? "value >= " + filter.value[0] + " and value <= " + filter.value[1] : "value = " + filter.value;
            break;
        case AttributeType.ENUM:
        case AttributeType.LOCALIZED_ENUM:
            valuePredicate = "value(key = \"" + filter.value + "\")";
            break;
        case AttributeType.LOCALIZED_STRING:
            valuePredicate = "value(" + locale.toLowerCase() + " = \"" + filter.value + "\")";
            break;
        case AttributeType.MONEY:
            valuePredicate = Array.isArray(filter.value)
                ? "value(centAmount >= " + filter.value[0] * 100 + " and centAmount <= " + filter.value[1] * 100 + " and currencyCode = \"" + currency + "\")"
                : "value(centAmount = " + filter.value + " and currencyCode = \"" + currency + "\")";
            break;
        case AttributeType.BOOLEAN:
            valuePredicate = "value = " + filter.value;
            break;
    }
    return "masterData(current(masterVariant(attributes(name = \"" + filter.name + "\" and " + valuePredicate + "))))";
};
var buildProductWhere = function (settings, search) {
    var acceptLanguage = settings.acceptLanguage;
    var predicates = [];
    if (search === null || search === void 0 ? void 0 : search.catId) {
        var catIds = (Array.isArray(search.catId) ? search.catId : [search.catId]).join('","');
        predicates.push("masterData(current(categories(id in (\"" + catIds + "\"))))");
    }
    if (search === null || search === void 0 ? void 0 : search.slug) {
        var predicate = acceptLanguage.map(function (locale) { return locale + "=\"" + search.slug + "\""; }).join(' or ');
        predicates.push("masterData(current(slug(" + predicate + ")))");
    }
    if (search === null || search === void 0 ? void 0 : search.id) {
        predicates.push("id=\"" + search.id + "\"");
    }
    if (search === null || search === void 0 ? void 0 : search.filters) {
        var filterPredicates = search.filters.map(function (f) { return mapFilterToPredicate(settings, f); }).join(' or ');
        if (filterPredicates) {
            predicates.push(filterPredicates);
        }
    }
    if (search === null || search === void 0 ? void 0 : search.key) {
        predicates.push("key=\"" + search.key + "\"");
    }
    if (search === null || search === void 0 ? void 0 : search.ids) {
        predicates.push("id in (\"" + search.ids.join('","') + "\")");
    }
    return predicates.join(' and ') || null;
};
var buildCategoryWhere = function (settings, search) {
    var acceptLanguage = settings.acceptLanguage;
    if (search === null || search === void 0 ? void 0 : search.catId) {
        return "id=\"" + search.catId + "\"";
    }
    if (search === null || search === void 0 ? void 0 : search.slug) {
        var predicate = acceptLanguage.map(function (locale) { return locale + "=\"" + search.slug + "\""; }).join(' or ');
        return "slug(" + predicate + ")";
    }
    if (search === null || search === void 0 ? void 0 : search.key) {
        return "key=\"" + search.key + "\"";
    }
    return undefined;
};
var buildCategoryFilter = function (settings, filter) {
    var acceptLanguage = settings.acceptLanguage;
    if (filter === null || filter === void 0 ? void 0 : filter.catId) {
        return ["id:\"" + filter.catId + "\""];
    }
    if (filter === null || filter === void 0 ? void 0 : filter.slug) {
        return ["slug." + acceptLanguage[0] + ":\"" + filter.slug + "\""];
    }
    if (filter === null || filter === void 0 ? void 0 : filter.key) {
        return ["key:\"" + filter.key + "\""];
    }
    return undefined;
};
var buildOrderWhere = function (search) {
    if (search === null || search === void 0 ? void 0 : search.id) {
        return "id=\"" + search.id + "\"";
    }
    if (search === null || search === void 0 ? void 0 : search.orderNumber) {
        return "orderNumber=\"" + search.orderNumber + "\"";
    }
    return null;
};

/**
 * @remarks References:
 * {@link CategoryData}
 */
var getCategory = function (context, params, customQuery) { return __awaiter(void 0, void 0, void 0, function () {
    var acceptLanguage, defaultVariables, categories, request;
    return __generator(this, function (_a) {
        switch (_a.label) {
            case 0:
                acceptLanguage = context.config.acceptLanguage;
                defaultVariables = params ? {
                    where: buildCategoryWhere(context.config, params),
                    limit: params.limit,
                    offset: params.offset,
                    acceptLanguage: acceptLanguage
                } : { acceptLanguage: acceptLanguage };
                categories = context.extendQuery(customQuery, { categories: { query: defaultQuery$6, variables: defaultVariables } }).categories;
                return [4 /*yield*/, context.client.query({
                        query: gql__default["default"](templateObject_1$g || (templateObject_1$g = __makeTemplateObject(["", ""], ["", ""])), categories.query),
                        variables: categories.variables,
                        fetchPolicy: 'no-cache'
                    })];
            case 1:
                request = _a.sent();
                return [2 /*return*/, request];
        }
    });
}); };
var getCategory$1 = getCategory;
var templateObject_1$g;

var defaultQuery$5 = gql__default["default"](templateObject_1$f || (templateObject_1$f = __makeTemplateObject(["\n  query ($filter: [SearchFilter!], $acceptLanguage: [Locale!]) {\n  categorySearch(filters: $filter) {\n    offset\n    count\n    total\n    results {\n      id\n      slug(acceptLanguage: $acceptLanguage)\n      name(acceptLanguage: $acceptLanguage)\n      description(acceptLanguage: $acceptLanguage)\n      childCount\n      stagedProductCount\n      parent {\n        ...DefaultCategorySearch\n        parent {\n          ...DefaultCategorySearch\n          parent {\n            ...DefaultCategorySearch\n          }\n        }\n      }\n      children {\n        ...DefaultCategorySearch\n      }\n    }\n  }\n}\n\nfragment DefaultCategorySearch on CategorySearch {\n  id\n  slug(acceptLanguage: $acceptLanguage)\n  name(acceptLanguage: $acceptLanguage)\n  childCount\n  stagedProductCount\n  children {\n    ...CategorySearchChildren\n    children {\n      ...CategorySearchChildren\n      children {\n        ...CategorySearchChildren\n      }\n    }\n  }\n}\n\nfragment CategorySearchChildren on CategorySearch {\n  id\n  slug(acceptLanguage: $acceptLanguage)\n  name(acceptLanguage: $acceptLanguage)\n  childCount\n  stagedProductCount\n}\n"], ["\n  query ($filter: [SearchFilter!], $acceptLanguage: [Locale!]) {\n  categorySearch(filters: $filter) {\n    offset\n    count\n    total\n    results {\n      id\n      slug(acceptLanguage: $acceptLanguage)\n      name(acceptLanguage: $acceptLanguage)\n      description(acceptLanguage: $acceptLanguage)\n      childCount\n      stagedProductCount\n      parent {\n        ...DefaultCategorySearch\n        parent {\n          ...DefaultCategorySearch\n          parent {\n            ...DefaultCategorySearch\n          }\n        }\n      }\n      children {\n        ...DefaultCategorySearch\n      }\n    }\n  }\n}\n\nfragment DefaultCategorySearch on CategorySearch {\n  id\n  slug(acceptLanguage: $acceptLanguage)\n  name(acceptLanguage: $acceptLanguage)\n  childCount\n  stagedProductCount\n  children {\n    ...CategorySearchChildren\n    children {\n      ...CategorySearchChildren\n      children {\n        ...CategorySearchChildren\n      }\n    }\n  }\n}\n\nfragment CategorySearchChildren on CategorySearch {\n  id\n  slug(acceptLanguage: $acceptLanguage)\n  name(acceptLanguage: $acceptLanguage)\n  childCount\n  stagedProductCount\n}\n"])));
var templateObject_1$f;

var categorySearch = function (context, params, customQuery) { return __awaiter(void 0, void 0, void 0, function () {
    var acceptLanguage, defaultVariables, categorySearch, request;
    return __generator(this, function (_a) {
        switch (_a.label) {
            case 0:
                acceptLanguage = context.config.acceptLanguage;
                defaultVariables = params ? {
                    filter: buildCategoryFilter(context.config, params),
                    limit: params.limit,
                    offset: params.offset,
                    acceptLanguage: acceptLanguage
                } : { acceptLanguage: acceptLanguage };
                categorySearch = context.extendQuery(customQuery, { categorySearch: { query: defaultQuery$5, variables: defaultVariables } }).categorySearch;
                return [4 /*yield*/, context.client.query({
                        query: gql__default["default"](templateObject_1$e || (templateObject_1$e = __makeTemplateObject(["", ""], ["", ""])), categorySearch.query),
                        variables: categorySearch.variables,
                        fetchPolicy: 'no-cache'
                    })];
            case 1:
                request = _a.sent();
                return [2 /*return*/, request];
        }
    });
}); };
var categorySearch$1 = categorySearch;
var templateObject_1$e;

var basicProfile = gql__default["default"](templateObject_1$d || (templateObject_1$d = __makeTemplateObject(["\n  ", "\n\n  query getBasicProfile($locale: Locale!, $acceptLanguage: [Locale!], $currency: Currency!) {\n    me {\n      activeCart {\n        ...DefaultCart\n      }\n    }\n  }\n"], ["\n  ", "\n\n  query getBasicProfile($locale: Locale!, $acceptLanguage: [Locale!], $currency: Currency!) {\n    me {\n      activeCart {\n        ...DefaultCart\n      }\n    }\n  }\n"])), CartFragment);
var fullProfile = gql__default["default"](templateObject_2 || (templateObject_2 = __makeTemplateObject(["\n  ", "\n  ", "\n\n  query getFullProfile($locale: Locale!, $acceptLanguage: [Locale!], $currency: Currency!) {\n    me {\n      activeCart {\n        ...DefaultCart\n      }\n      customer {\n        ...DefaultCustomer\n      }\n    }\n  }\n"], ["\n  ", "\n  ", "\n\n  query getFullProfile($locale: Locale!, $acceptLanguage: [Locale!], $currency: Currency!) {\n    me {\n      activeCart {\n        ...DefaultCart\n      }\n      customer {\n        ...DefaultCustomer\n      }\n    }\n  }\n"])), CartFragment, CustomerFragment);
var templateObject_1$d, templateObject_2;

/**
 * @remarks References:
 * {@link GetMeParams}, {@link OrdersData}
 */
var getMe = function (context, params, customQuery) {
    if (params === void 0) { params = {}; }
    return __awaiter(void 0, void 0, void 0, function () {
        var _a, locale, acceptLanguage, currency, customer, defaultVariables, _b, getBasicProfile, getFullProfile, profile, request;
        return __generator(this, function (_c) {
            switch (_c.label) {
                case 0:
                    _a = context.config, locale = _a.locale, acceptLanguage = _a.acceptLanguage, currency = _a.currency;
                    customer = params.customer;
                    defaultVariables = {
                        locale: locale,
                        acceptLanguage: acceptLanguage,
                        currency: currency
                    };
                    _b = context.extendQuery(customQuery, {
                        getBasicProfile: { query: basicProfile, variables: defaultVariables },
                        getFullProfile: { query: fullProfile, variables: defaultVariables }
                    }), getBasicProfile = _b.getBasicProfile, getFullProfile = _b.getFullProfile;
                    profile = customer ? getFullProfile : getBasicProfile;
                    return [4 /*yield*/, context.client.query({
                            query: gql__default["default"](templateObject_1$c || (templateObject_1$c = __makeTemplateObject(["", ""], ["", ""])), profile.query),
                            variables: profile.variables,
                            fetchPolicy: 'no-cache'
                        })];
                case 1:
                    request = _c.sent();
                    return [2 /*return*/, request];
            }
        });
    });
};
var getMe$1 = getMe;
var templateObject_1$c;

var defaultQuery$4 = gql__default["default"](templateObject_1$b || (templateObject_1$b = __makeTemplateObject(["\n  ", "\n\n  query getMyOrders($where: String, $sort: [String!], $limit: Int, $offset: Int, $locale: Locale!, $acceptLanguage: [Locale!], $currency: Currency!) {\n    me {\n      orders(where: $where, sort: $sort, limit: $limit, offset: $offset) {\n        results {\n          ...DefaultOrder\n        }\n        total\n        offset\n        count\n      }\n    }\n  }\n"], ["\n  ", "\n\n  query getMyOrders($where: String, $sort: [String!], $limit: Int, $offset: Int, $locale: Locale!, $acceptLanguage: [Locale!], $currency: Currency!) {\n    me {\n      orders(where: $where, sort: $sort, limit: $limit, offset: $offset) {\n        results {\n          ...DefaultOrder\n        }\n        total\n        offset\n        count\n      }\n    }\n  }\n"])), OrderFragment);
var templateObject_1$b;

var getOrders = function (context, params, customQuery) { return __awaiter(void 0, void 0, void 0, function () {
    var _a, locale, acceptLanguage, currency, defaultVariables, getMyOrders, request;
    return __generator(this, function (_b) {
        switch (_b.label) {
            case 0:
                _a = context.config, locale = _a.locale, acceptLanguage = _a.acceptLanguage, currency = _a.currency;
                defaultVariables = {
                    where: buildOrderWhere(params),
                    sort: params.sort,
                    limit: params.limit,
                    offset: params.offset,
                    acceptLanguage: acceptLanguage,
                    locale: locale,
                    currency: currency
                };
                getMyOrders = context.extendQuery(customQuery, { getMyOrders: { query: defaultQuery$4, variables: defaultVariables } }).getMyOrders;
                return [4 /*yield*/, context.client.query({
                        query: gql__default["default"](templateObject_1$a || (templateObject_1$a = __makeTemplateObject(["", ""], ["", ""])), getMyOrders.query),
                        variables: getMyOrders.variables,
                        fetchPolicy: 'no-cache'
                    })];
            case 1:
                request = _b.sent();
                return [2 /*return*/, request];
        }
    });
}); };
var getOrders$1 = getOrders;
var templateObject_1$a;

var defaultQuery$3 = gql__default["default"](templateObject_1$9 || (templateObject_1$9 = __makeTemplateObject(["\n  ", "\n  ", "\n\n  fragment Images on ProductVariant {\n    images {\n      url\n      label\n    }\n  }\n\n  fragment Price on ProductVariant {\n    price(currency: $currency, country: $country, channelId: $channelId) {\n      ...DefaultProductPrice\n    }\n  }\n\n  fragment Attributes on ProductVariant {\n    attributesRaw {\n      name\n      value\n      attributeDefinition {\n        type {\n          name\n        }\n        label(locale: $locale)\n      }\n    }\n  }\n  \n  fragment Availability on ProductVariant {\n    availability {\n      noChannel {\n        isOnStock\n        restockableInDays\n        availableQuantity\n      }\n      channels(\n        includeChannelIds: $includeChannelIds \n        excludeChannelIds: $excludeChannelIds \n        limit: $channelLimit\n        offset: $channelOffset\n      ) {\n        limit\n        offset\n        total\n        results {\n          channelRef {\n            id\n          }\n          availability {\n            isOnStock\n            restockableInDays\n            availableQuantity\n          }\n          channel {\n            ...ChannelFragment\n          }\n        }\n      }\n    }\n  }\n  \n  fragment DefaultVariant on ProductVariant {\n    id\n    sku\n    ...Images\n    ...Price\n    ...Attributes\n    ...Availability\n  }\n\n  query products(\n    $where: String\n    $sort: [String!]\n    $limit: Int\n    $offset: Int\n    $skus: [String!]\n    $locale: Locale!\n    $acceptLanguage: [Locale!]\n    $currency: Currency!\n    $country: Country!\n    $channelId: String\n    $includeChannelIds: [String!]\n    $excludeChannelIds: [String!]\n    $channelLimit: Int\n    $channelOffset: Int\n  ) {\n    products(\n      where: $where\n      sort: $sort\n      limit: $limit\n      offset: $offset\n      skus: $skus\n    ) {\n      offset\n      count\n      total\n      results {\n        id\n        reviewRatingStatistics {\t\n          averageRating,\n          ratingsDistribution,\n          count\n        }\n        masterData {\n          current {\n            slug(acceptLanguage: $acceptLanguage)\n            name(acceptLanguage: $acceptLanguage)\n            metaTitle(acceptLanguage: $acceptLanguage)\n            metaKeywords(acceptLanguage: $acceptLanguage)\n            metaDescription(acceptLanguage: $acceptLanguage)\n            description(acceptLanguage: $acceptLanguage)\n            categoriesRef {\n              id\n            }\n            allVariants {\n              ...DefaultVariant\n            }\n            masterVariant {\n              ...DefaultVariant\n            }\n          }\n        }\n      }\n    }\n  }\n"], ["\n  ", "\n  ", "\n\n  fragment Images on ProductVariant {\n    images {\n      url\n      label\n    }\n  }\n\n  fragment Price on ProductVariant {\n    price(currency: $currency, country: $country, channelId: $channelId) {\n      ...DefaultProductPrice\n    }\n  }\n\n  fragment Attributes on ProductVariant {\n    attributesRaw {\n      name\n      value\n      attributeDefinition {\n        type {\n          name\n        }\n        label(locale: $locale)\n      }\n    }\n  }\n  \n  fragment Availability on ProductVariant {\n    availability {\n      noChannel {\n        isOnStock\n        restockableInDays\n        availableQuantity\n      }\n      channels(\n        includeChannelIds: $includeChannelIds \n        excludeChannelIds: $excludeChannelIds \n        limit: $channelLimit\n        offset: $channelOffset\n      ) {\n        limit\n        offset\n        total\n        results {\n          channelRef {\n            id\n          }\n          availability {\n            isOnStock\n            restockableInDays\n            availableQuantity\n          }\n          channel {\n            ...ChannelFragment\n          }\n        }\n      }\n    }\n  }\n  \n  fragment DefaultVariant on ProductVariant {\n    id\n    sku\n    ...Images\n    ...Price\n    ...Attributes\n    ...Availability\n  }\n\n  query products(\n    $where: String\n    $sort: [String!]\n    $limit: Int\n    $offset: Int\n    $skus: [String!]\n    $locale: Locale!\n    $acceptLanguage: [Locale!]\n    $currency: Currency!\n    $country: Country!\n    $channelId: String\n    $includeChannelIds: [String!]\n    $excludeChannelIds: [String!]\n    $channelLimit: Int\n    $channelOffset: Int\n  ) {\n    products(\n      where: $where\n      sort: $sort\n      limit: $limit\n      offset: $offset\n      skus: $skus\n    ) {\n      offset\n      count\n      total\n      results {\n        id\n        reviewRatingStatistics {\t\n          averageRating,\n          ratingsDistribution,\n          count\n        }\n        masterData {\n          current {\n            slug(acceptLanguage: $acceptLanguage)\n            name(acceptLanguage: $acceptLanguage)\n            metaTitle(acceptLanguage: $acceptLanguage)\n            metaKeywords(acceptLanguage: $acceptLanguage)\n            metaDescription(acceptLanguage: $acceptLanguage)\n            description(acceptLanguage: $acceptLanguage)\n            categoriesRef {\n              id\n            }\n            allVariants {\n              ...DefaultVariant\n            }\n            masterVariant {\n              ...DefaultVariant\n            }\n          }\n        }\n      }\n    }\n  }\n"])), ProductPriceFragment, ChannelFragment);
var templateObject_1$9;

/**
 * @remarks References:
 * {@link ProductData}
 */
var getProduct = function (context, params, customQuery) { return __awaiter(void 0, void 0, void 0, function () {
    var _a, locale, acceptLanguage, currency, country, defaultVariables, products, request, error_1;
    var _b, _c;
    return __generator(this, function (_d) {
        switch (_d.label) {
            case 0:
                _a = context.config, locale = _a.locale, acceptLanguage = _a.acceptLanguage, currency = _a.currency, country = _a.country;
                defaultVariables = {
                    where: buildProductWhere(context.config, params),
                    skus: params.skus,
                    limit: params.limit,
                    offset: params.offset,
                    channelId: params.channelId,
                    locale: locale,
                    acceptLanguage: acceptLanguage,
                    currency: currency,
                    country: country
                };
                products = context.extendQuery(customQuery, { products: { query: defaultQuery$3, variables: defaultVariables } }).products;
                _d.label = 1;
            case 1:
                _d.trys.push([1, 3, , 4]);
                return [4 /*yield*/, context.client.query({
                        query: gql__default["default"](templateObject_1$8 || (templateObject_1$8 = __makeTemplateObject(["", ""], ["", ""])), products.query),
                        variables: products.variables,
                        // temporary, seems like bug in apollo:
                        // @link: https://github.com/apollographql/apollo-client/issues/3234
                        fetchPolicy: 'no-cache'
                    })];
            case 2:
                request = _d.sent();
                return [2 /*return*/, request];
            case 3:
                error_1 = _d.sent();
                throw ((_b = error_1.graphQLErrors) === null || _b === void 0 ? void 0 : _b[0]) || ((_c = error_1.networkError) === null || _c === void 0 ? void 0 : _c.result) || error_1;
            case 4: return [2 /*return*/];
        }
    });
}); };
var getProduct$1 = getProduct;
var templateObject_1$8;

var defaultQuery$2 = gql__default["default"](templateObject_1$7 || (templateObject_1$7 = __makeTemplateObject(["\n  ", "\n\n  query shippingMethods($acceptLanguage: [Locale!], $cartId: String!) {\n    shippingMethods: shippingMethodsByCart(id: $cartId) {\n      ...DefaultShippingMethod\n    }\n  }\n"], ["\n  ", "\n\n  query shippingMethods($acceptLanguage: [Locale!], $cartId: String!) {\n    shippingMethods: shippingMethodsByCart(id: $cartId) {\n      ...DefaultShippingMethod\n    }\n  }\n"])), ShippingMethodFragment);
var templateObject_1$7;

/**
 * @remarks References:
 * {@link ShippingMethodData}
 */
var getShippingMethods = function (context, cartId, customQuery) { return __awaiter(void 0, void 0, void 0, function () {
    var acceptLanguage, defaultVariables, shippingMethods;
    return __generator(this, function (_a) {
        switch (_a.label) {
            case 0:
                acceptLanguage = context.config.acceptLanguage;
                defaultVariables = {
                    acceptLanguage: acceptLanguage,
                    cartId: cartId
                };
                shippingMethods = context.extendQuery(customQuery, { shippingMethods: { query: defaultQuery$2, variables: defaultVariables } }).shippingMethods;
                return [4 /*yield*/, context.client.query({
                        query: gql__default["default"](templateObject_1$6 || (templateObject_1$6 = __makeTemplateObject(["", ""], ["", ""])), shippingMethods.query),
                        variables: shippingMethods.variables,
                        fetchPolicy: 'no-cache'
                    })];
            case 1: return [2 /*return*/, _a.sent()];
        }
    });
}); };
var getShippingMethods$1 = getShippingMethods;
var templateObject_1$6;

var isGuest = function (context) {
    var config = context.config;
    if (typeof config.handleIsGuest === 'function') {
        return config.handleIsGuest(context);
    }
    var token = context.config.auth.onTokenRead();
    return !isAnonymousSession(token) && !isUserSession(token);
};
var isGuest$1 = isGuest;

var isLoggedIn = function (context) {
    var config = context.config;
    if (typeof config.handleIsLoggedIn === 'function') {
        return config.handleIsLoggedIn(context);
    }
    return isUserSession(context.config.auth.onTokenRead());
};
var isLoggedIn$1 = isLoggedIn;

/**
 * @remarks References:
 * {@link CartDetails}, {@link ReferenceInput}, {@link CartResponse}
 */
var removeCartCoupon = function (context, _a, discountCode, customQuery) {
    var id = _a.id, version = _a.version;
    return __awaiter(void 0, void 0, void 0, function () {
        return __generator(this, function (_b) {
            switch (_b.label) {
                case 0: return [4 /*yield*/, updateCart$1(context, {
                        id: id,
                        version: version,
                        actions: [removeDiscountCodeAction(discountCode)]
                    }, customQuery)];
                case 1: return [2 /*return*/, _b.sent()];
            }
        });
    });
};
var removeCartCoupon$1 = removeCartCoupon;

/**
 * @remarks References:
 * {@link CartDetails}, {@link @vue-storefront/commercetools-api#LineItem}, {@link CartResponse}
 */
var removeFromCart = function (context, _a, product, customQuery) {
    var id = _a.id, version = _a.version;
    return __awaiter(void 0, void 0, void 0, function () {
        return __generator(this, function (_b) {
            switch (_b.label) {
                case 0: return [4 /*yield*/, updateCart$1(context, {
                        id: id,
                        version: version,
                        actions: [createRemoveLineItemAction(product)]
                    }, customQuery)];
                case 1: return [2 /*return*/, _b.sent()];
            }
        });
    });
};
var removeFromCart$1 = removeFromCart;

/**
 * @remarks References:
 * {@link CartDetails}, {@link @vue-storefront/commercetools-api#LineItem}, {@link CartResponse}
 */
var updateCartQuantity = function (context, _a, product, customQuery) {
    var id = _a.id, version = _a.version;
    return __awaiter(void 0, void 0, void 0, function () {
        return __generator(this, function (_b) {
            switch (_b.label) {
                case 0: return [4 /*yield*/, updateCart$1(context, {
                        id: id,
                        version: version,
                        actions: [createChangeLineItemQuantityAction(product)]
                    }, customQuery)];
                case 1: return [2 /*return*/, _b.sent()];
            }
        });
    });
};
var updateCartQuantity$1 = updateCartQuantity;

/**
 * @remarks References:
 * {@link @vue-storefront/commercetools-api#Cart}, {@link @vue-storefront/commercetools-api#Address}, {@link CartResponse}
 */
var updateShippingDetails = function (context, cart, shippingDetails, customQuery) { return __awaiter(void 0, void 0, void 0, function () {
    var cartResponse;
    return __generator(this, function (_a) {
        switch (_a.label) {
            case 0: return [4 /*yield*/, updateCart$1(context, {
                    id: cart.id,
                    version: cart.version,
                    actions: [setShippingAddressAction(shippingDetails)]
                }, customQuery)];
            case 1:
                cartResponse = _a.sent();
                return [2 /*return*/, cartResponse];
        }
    });
}); };
var updateShippingDetails$1 = updateShippingDetails;

var defaultQuery$1 = gql__default["default"](templateObject_1$5 || (templateObject_1$5 = __makeTemplateObject(["\n  ", "\n\n  mutation customerResetPassword($tokenValue: String!, $newPassword: String!, $storeKey: KeyReferenceInput) {\n    customerResetPassword(tokenValue: $tokenValue, newPassword: $newPassword, storeKey: $storeKey) {\n      ...DefaultCustomer\n    }\n  }\n"], ["\n  ", "\n\n  mutation customerResetPassword($tokenValue: String!, $newPassword: String!, $storeKey: KeyReferenceInput) {\n    customerResetPassword(tokenValue: $tokenValue, newPassword: $newPassword, storeKey: $storeKey) {\n      ...DefaultCustomer\n    }\n  }\n"])), CustomerFragment);
var templateObject_1$5;

/**
 * @remarks References:
 * {@link ResetPasswordResponse}
 */
var customerResetPassword = function (context, tokenValue, newPassword, customQuery) { return __awaiter(void 0, void 0, void 0, function () {
    var _a, locale, acceptLanguage, defaultVariables, customerResetPassword, error_1;
    return __generator(this, function (_b) {
        switch (_b.label) {
            case 0:
                _a = context.config, locale = _a.locale, acceptLanguage = _a.acceptLanguage;
                defaultVariables = tokenValue && newPassword
                    ? {
                        locale: locale,
                        acceptLanguage: acceptLanguage,
                        tokenValue: tokenValue,
                        newPassword: newPassword
                    }
                    : { acceptLanguage: acceptLanguage };
                customerResetPassword = context.extendQuery(customQuery, { customerResetPassword: { query: defaultQuery$1, variables: defaultVariables } }).customerResetPassword;
                _b.label = 1;
            case 1:
                _b.trys.push([1, 3, , 4]);
                return [4 /*yield*/, context.client.mutate({
                        mutation: gql__default["default"](templateObject_1$4 || (templateObject_1$4 = __makeTemplateObject(["", ""], ["", ""])), customerResetPassword.query),
                        variables: customerResetPassword.variables,
                        fetchPolicy: 'no-cache'
                    })];
            case 2: return [2 /*return*/, _b.sent()];
            case 3:
                error_1 = _b.sent();
                core.Logger.error("Cannot set new password after reset. Error: " + error_1);
                throw error_1;
            case 4: return [2 /*return*/];
        }
    });
}); };
var customerResetPassword$1 = customerResetPassword;
var templateObject_1$4;

var defaultQuery = gql__default["default"](templateObject_1$3 || (templateObject_1$3 = __makeTemplateObject(["\n  mutation customerCreatePasswordResetToken($email: String!, $storeKey: KeyReferenceInput) {\n    customerCreatePasswordResetToken(email: $email, storeKey: $storeKey) {\n      customerId\n      expiresAt\n      value\n      id\n      version\n      createdAt\n      lastModifiedAt\n      createdBy {\n        isPlatformClient\n        externalUserId\n        anonymousId\n        clientId\n        customerRef {\n          typeId\n          id\n        }\n        userRef {\n          typeId\n          id\n        }\n      }\n      lastModifiedBy {\n        isPlatformClient\n        externalUserId\n        anonymousId\n        clientId\n        customerRef {\n          typeId\n          id\n        }\n        userRef {\n          typeId\n          id\n        }\n      }\n    }\n  }\n"], ["\n  mutation customerCreatePasswordResetToken($email: String!, $storeKey: KeyReferenceInput) {\n    customerCreatePasswordResetToken(email: $email, storeKey: $storeKey) {\n      customerId\n      expiresAt\n      value\n      id\n      version\n      createdAt\n      lastModifiedAt\n      createdBy {\n        isPlatformClient\n        externalUserId\n        anonymousId\n        clientId\n        customerRef {\n          typeId\n          id\n        }\n        userRef {\n          typeId\n          id\n        }\n      }\n      lastModifiedBy {\n        isPlatformClient\n        externalUserId\n        anonymousId\n        clientId\n        customerRef {\n          typeId\n          id\n        }\n        userRef {\n          typeId\n          id\n        }\n      }\n    }\n  }\n"])));
var templateObject_1$3;

/**
 * @remarks References:
 * {@link CreatePasswordResetTokenResponse}
 */
var customerCreatePasswordResetToken = function (context, email, customQuery) { return __awaiter(void 0, void 0, void 0, function () {
    var _a, locale, acceptLanguage, defaultVariables, customerCreatePasswordResetToken, error_1;
    return __generator(this, function (_b) {
        switch (_b.label) {
            case 0:
                _a = context.config, locale = _a.locale, acceptLanguage = _a.acceptLanguage;
                defaultVariables = email
                    ? {
                        locale: locale,
                        acceptLanguage: acceptLanguage,
                        email: email
                    }
                    : { acceptLanguage: acceptLanguage };
                customerCreatePasswordResetToken = context.extendQuery(customQuery, { customerCreatePasswordResetToken: { query: defaultQuery, variables: defaultVariables } }).customerCreatePasswordResetToken;
                _b.label = 1;
            case 1:
                _b.trys.push([1, 3, , 4]);
                return [4 /*yield*/, context.client.mutate({
                        mutation: gql__default["default"](templateObject_1$2 || (templateObject_1$2 = __makeTemplateObject(["", ""], ["", ""])), customerCreatePasswordResetToken.query),
                        variables: customerCreatePasswordResetToken.variables,
                        fetchPolicy: 'no-cache'
                    })];
            case 2: return [2 /*return*/, _b.sent()];
            case 3:
                error_1 = _b.sent();
                core.Logger.error("Cannot create password reset token. Error: " + error_1);
                throw error_1;
            case 4: return [2 /*return*/];
        }
    });
}); };
var customerCreatePasswordResetToken$1 = customerCreatePasswordResetToken;
var templateObject_1$2;

var storesData = gql__default["default"](templateObject_1$1 || (templateObject_1$1 = __makeTemplateObject(["\n  ", "\n\n  query stores(\n    $where: String\n    $sort: [String!]\n    $limit: Int\n    $offset: Int\n    $locale: Locale!\n  ) {\n    stores(\n      where: $where\n      sort: $sort\n      limit: $limit\n      offset: $offset\n    ) {\n      ...StoreQueryResultFragment\n    }\n  }\n"], ["\n  ", "\n\n  query stores(\n    $where: String\n    $sort: [String!]\n    $limit: Int\n    $offset: Int\n    $locale: Locale!\n  ) {\n    stores(\n      where: $where\n      sort: $sort\n      limit: $limit\n      offset: $offset\n    ) {\n      ...StoreQueryResultFragment\n    }\n  }\n"])), StoreQueryResultFragment);
var templateObject_1$1;

/**
 * @remarks References:
 * {@link GetStoresParams}, {@link StoreQueryResult}
 */
function getStores(context, params) {
    return __awaiter(this, void 0, void 0, function () {
        var variables, customQuery, getStoresData, response;
        return __generator(this, function (_a) {
            switch (_a.label) {
                case 0:
                    variables = { locale: context.config.locale };
                    customQuery = Object(params).customQuery;
                    getStoresData = context.extendQuery(customQuery, {
                        getStoresData: { query: storesData, variables: variables }
                    }).getStoresData;
                    return [4 /*yield*/, context.client.query({
                            query: gql__default["default"](templateObject_1 || (templateObject_1 = __makeTemplateObject(["", ""], ["", ""])), getStoresData.query),
                            variables: getStoresData.variables,
                            fetchPolicy: 'no-cache'
                        })];
                case 1:
                    response = _a.sent();
                    return [2 /*return*/, response.data.stores];
            }
        });
    });
}
var templateObject_1;

var api = /*#__PURE__*/Object.freeze({
    __proto__: null,
    addToCart: addToCart$1,
    applyCartCoupon: applyCartCoupon$1,
    createCart: createCart$1,
    createMyOrderFromCart: createMyOrderFromCart$1,
    customerChangeMyPassword: customerChangeMyPassword$1,
    customerSignMeIn: customerSignMeIn$1,
    customerSignMeUp: customerSignMeUp$1,
    customerSignOut: customerSignOut$1,
    customerUpdateMe: customerUpdateMe$1,
    deleteCart: deleteCart$1,
    getCart: getCart$1,
    getCategory: getCategory$1,
    categorySearch: categorySearch$1,
    getMe: getMe$1,
    getOrders: getOrders$1,
    getProduct: getProduct$1,
    getShippingMethods: getShippingMethods$1,
    isGuest: isGuest$1,
    isLoggedIn: isLoggedIn$1,
    removeCartCoupon: removeCartCoupon$1,
    removeFromCart: removeFromCart$1,
    updateCart: updateCart$1,
    updateCartQuantity: updateCartQuantity$1,
    updateShippingDetails: updateShippingDetails$1,
    customerResetPassword: customerResetPassword$1,
    customerCreatePasswordResetToken: customerCreatePasswordResetToken$1,
    getStores: getStores
});

var emailExtension = {
    name: 'logMailExtension',
    extendApiMethods: {
        customerCreatePasswordResetToken: function (context, email) {
            var _a, _b;
            return __awaiter(this, void 0, void 0, function () {
                var response, token, emailObject;
                return __generator(this, function (_c) {
                    switch (_c.label) {
                        case 0: return [4 /*yield*/, customerCreatePasswordResetToken$1(context, email)];
                        case 1:
                            response = _c.sent();
                            token = (_b = (_a = response === null || response === void 0 ? void 0 : response.data) === null || _a === void 0 ? void 0 : _a.customerCreatePasswordResetToken) === null || _b === void 0 ? void 0 : _b.value;
                            emailObject = {
                                to: email,
                                from: 'password-recovery@vue-storefront.io',
                                subject: "Password recovery for " + email,
                                html: "<a href='/reset-password?token=" + token + "'>Reset your password by clicking this link</a>"
                            };
                            console.log(JSON.stringify(emailObject));
                            return [2 /*return*/, response];
                    }
                });
            });
        }
    }
};

var defaultSettings = {
    locale: 'en',
    currency: 'USD',
    country: 'US',
    acceptLanguage: ['en'],
    auth: {
        onTokenChange: function () { },
        onTokenRead: function () { return ''; },
        onTokenRemove: function () { }
    },
    storeService: {
        changeCurrentStore: function () { }
    },
    cookies: {
        currencyCookieName: core.VSF_CURRENCY_COOKIE,
        countryCookieName: core.VSF_COUNTRY_COOKIE,
        localeCookieName: core.VSF_LOCALE_COOKIE,
        storeCookieName: core.VSF_STORE_COOKIE
    }
};

function getInternationalizationConfiguration(request, configuration) {
    var cookieSettings = configuration.cookies || defaultSettings.cookies;
    var currencyCookieName = cookieSettings.currencyCookieName, countryCookieName = cookieSettings.countryCookieName, localeCookieName = cookieSettings.localeCookieName, storeCookieName = cookieSettings.storeCookieName;
    var locale = request.cookies[localeCookieName] || configuration.locale || defaultSettings.locale;
    var currency = request.cookies[currencyCookieName] || configuration.currency || defaultSettings.currency;
    var country = request.cookies[countryCookieName] || configuration.country || defaultSettings.country;
    var store = request.cookies[storeCookieName] || configuration.store;
    return { currency: currency, country: country, locale: locale, store: store };
}
var internationalizationExtension = {
    name: 'internationalizationExtension',
    hooks: function (request) {
        return {
            beforeCreate: function (_a) {
                var configuration = _a.configuration;
                return (__assign(__assign({}, configuration), getInternationalizationConfiguration(request, configuration)));
            }
        };
    }
};

/**
 * Name of the cookie storing the commercetools access token.
 */
var CT_COOKIE_NAME = 'vsf-commercetools-token';
var TokenType;
(function (TokenType) {
    TokenType["ServerAccessToken"] = "ServerAccessToken";
    TokenType["GuestAccessToken"] = "GuestAccessToken";
    TokenType["AnonymousAccessToken"] = "AnonymousAccessToken";
    TokenType["ExistingAccessToken"] = "ExistingAccessToken";
    TokenType["UserAccessToken"] = "UserAccessToken";
})(TokenType || (TokenType = {}));

/**
 * Creates an authentication SDK from the commercetools package.
 */
function createAuthClient(_a) {
    var host = _a.authHost, projectKey = _a.projectKey, clientId = _a.clientId, clientSecret = _a.clientSecret, scopes = _a.scopes;
    return new SdkAuth__default["default"]({
        host: host,
        projectKey: projectKey,
        disableRefreshToken: false,
        credentials: {
            clientId: clientId,
            clientSecret: clientSecret
        },
        scopes: scopes,
        fetch: fetch__default["default"]
    });
}
/**
 * Creates a token provider from the commercetools package.
 */
function createTokenProvider(_a) {
    var configuration = _a.configuration, sdkAuth = _a.sdkAuth, tokenType = _a.tokenType, apolloReq = _a.apolloReq;
    var _b = configuration.serverApi || configuration.api, clientId = _b.clientId, clientSecret = _b.clientSecret, scopes = _b.scopes;
    var parameters = { sdkAuth: sdkAuth };
    var currentToken = null;
    switch (tokenType) {
        /**
          * Creates server access token for operations that require elevated permissions. This token is not saved in the cookie.
        */
        case TokenType.ServerAccessToken:
            parameters = __assign(__assign({}, parameters), { fetchTokenInfo: function (sdkAuthInstance) { return sdkAuthInstance.clientCredentialsFlow({ credentials: { clientId: clientId, clientSecret: clientSecret }, scopes: scopes }); } });
            break;
        /**
          * Creates guest access token for all guest requests. This token is only stored on the server and not in the cookies.
        */
        case TokenType.GuestAccessToken:
            parameters = __assign(__assign({}, parameters), { fetchTokenInfo: function (sdkAuthInstance) { return sdkAuthInstance.clientCredentialsFlow(); } });
            break;
        /**
          * Creates anonymous access token for guests who just added the items to the cart/wishlist. This token is saved in the cookie.
        */
        case TokenType.AnonymousAccessToken:
            parameters = __assign(__assign({}, parameters), { fetchTokenInfo: function (sdkAuthInstance) { return sdkAuthInstance.anonymousFlow(); }, onTokenInfoChanged: function (tokenInfo) { return configuration.auth.onTokenChange(tokenInfo); }, onTokenInfoRefreshed: function (tokenInfo) { return configuration.auth.onTokenChange(tokenInfo); } });
            break;
        /**
          * Creates a new token provider for the anonymous or user token from the request’s cookie.
        */
        case TokenType.ExistingAccessToken:
            currentToken = configuration.auth.onTokenRead();
            parameters = __assign(__assign({}, parameters), { onTokenInfoChanged: function (tokenInfo) { return configuration.auth.onTokenChange(tokenInfo); }, onTokenInfoRefreshed: function (tokenInfo) { return configuration.auth.onTokenChange(tokenInfo); } });
            break;
        /**
          * Creates user access token for the user who just logged in or registered a new account. This token is saved in the cookie.
        */
        case TokenType.UserAccessToken:
            var _c = apolloReq.variables.draft, email_1 = _c.email, password_1 = _c.password;
            parameters = __assign(__assign({}, parameters), { fetchTokenInfo: function (sdkAuthInstance) { return sdkAuthInstance.customerPasswordFlow({ username: email_1, password: password_1 }); }, onTokenInfoChanged: function (tokenInfo) { return configuration.auth.onTokenChange(tokenInfo); }, onTokenInfoRefreshed: function (tokenInfo) { return configuration.auth.onTokenChange(tokenInfo); } });
            break;
    }
    return new SdkAuth.TokenProvider(parameters, currentToken);
}
/**
 * Create helpers from the commercetools SDK package.
 */
function createSdkHelpers(configuration, tokenType, apolloReq) {
    var sdkAuth = createAuthClient(configuration.api);
    var tokenProvider = createTokenProvider({
        configuration: configuration,
        sdkAuth: sdkAuth,
        tokenType: tokenType,
        apolloReq: apolloReq
    });
    return {
        sdkAuth: sdkAuth,
        tokenProvider: tokenProvider
    };
}

function parseToken(rawToken) {
    try {
        return JSON.parse(rawToken);
    }
    catch (e) {
        return null;
    }
}
var tokenExtension = {
    name: 'tokenExtension',
    extendApp: function (_a) {
        var configuration = _a.configuration;
        core.Logger.debug('Generating server access token');
        var serverTokenProvider = createSdkHelpers(configuration, TokenType.ServerAccessToken).tokenProvider;
        core.Logger.debug('Successfully generated server access token');
        core.Logger.debug('Generating guest access token');
        var tokenProvider = createSdkHelpers(configuration, TokenType.GuestAccessToken).tokenProvider;
        core.Logger.debug('Successfully generated guest access token');
        configuration.serverTokenProvider = serverTokenProvider;
        configuration.guestTokenProvider = tokenProvider;
    },
    hooks: function (request, response) {
        var currentToken = parseToken(request.cookies[CT_COOKIE_NAME]);
        var currentTokenProvider = {};
        /**
         * Set token provider.
         */
        function setTokenProvider(tokenProvider) {
            currentTokenProvider = tokenProvider;
        }
        /**
         * Get token provider.
         */
        function getTokenProvider() {
            return currentTokenProvider;
        }
        /**
         * Updates token cookie.
         */
        function onTokenChange(token) {
            currentToken = token;
            var options = __assign(__assign({}, ((token === null || token === void 0 ? void 0 : token.expires_at) && { expires: new Date(token.expires_at) })), { httpOnly: true, secure: request.secure });
            return response.cookie(CT_COOKIE_NAME, JSON.stringify(token), options);
        }
        /**
         * Returns current access token.
         */
        function onTokenRead() {
            return currentToken;
        }
        /**
         * Removes token cookie.
         */
        function onTokenRemove() {
            currentToken = null;
            return response.clearCookie(CT_COOKIE_NAME);
        }
        return {
            beforeCreate: function (_a) {
                var configuration = _a.configuration;
                return (__assign(__assign({}, configuration), { auth: {
                        onTokenChange: onTokenChange,
                        onTokenRead: onTokenRead,
                        onTokenRemove: onTokenRemove,
                        setTokenProvider: setTokenProvider,
                        getTokenProvider: getTokenProvider
                    } }));
            }
        };
    }
};

/**
 * Returns integration extensions based on the environment mode.
 */
function getExtensions() {
    var extensions = [
        internationalizationExtension,
        tokenExtension
    ];
    if (process.env.NODE_ENV === 'development') {
        extensions.push(emailExtension);
    }
    return extensions;
}

var restrictedOperations = {
    server: [
        'customerResetPassword',
        'customerCreatePasswordResetToken',
        'createReview',
        'reviews'
    ],
    anonymous: [
        'createCart',
        'createMyShoppingList'
    ],
    user: [
        'customerSignMeIn',
        'customerSignMeUp'
    ]
};
function isServerOperation(configuration, operationName) {
    var _a;
    var operations = __spreadArray(__spreadArray([], restrictedOperations.server, true), (((_a = configuration === null || configuration === void 0 ? void 0 : configuration.serverApi) === null || _a === void 0 ? void 0 : _a.operations) || []), true);
    return operations.includes(operationName);
}
function isAnonymousOperation(operationName) {
    return restrictedOperations.anonymous.includes(operationName);
}
function isUserOperation(operationName) {
    return restrictedOperations.user.includes(operationName);
}

/**
 * Returns access token for the Server Middleware. It usually has more permissions than anonymous / user access token.
 *
 * If the configuration doesn't specify server-specific API client configuration, it will fallback to customer access tokens configuration.
 */
function getServerAccessToken(_a) {
    var configuration = _a.configuration, apolloReq = _a.apolloReq;
    return __awaiter(this, void 0, void 0, function () {
        var currentToken;
        return __generator(this, function (_b) {
            switch (_b.label) {
                case 0:
                    core.Logger.debug("Retrieving server access token for operation \"" + apolloReq.operationName + "\"");
                    configuration.auth.setTokenProvider(configuration.serverTokenProvider);
                    return [4 /*yield*/, configuration.serverTokenProvider.getTokenInfo()];
                case 1:
                    currentToken = _b.sent();
                    core.Logger.debug("Successfully retrieved server access token for operation \"" + apolloReq.operationName + "\"");
                    return [2 /*return*/, currentToken];
            }
        });
    });
}
/**
 * Returns guest access token.
 */
function getGuestAccessToken(_a) {
    var configuration = _a.configuration;
    return __awaiter(this, void 0, void 0, function () {
        var currentToken;
        return __generator(this, function (_b) {
            switch (_b.label) {
                case 0:
                    core.Logger.debug('Retrieving guest access token from token provider for guest operation');
                    configuration.auth.setTokenProvider(configuration.guestTokenProvider);
                    return [4 /*yield*/, configuration.guestTokenProvider.getTokenInfo()];
                case 1:
                    currentToken = _b.sent();
                    core.Logger.debug('Successfully retrieved guest access token from token provider');
                    return [2 /*return*/, currentToken];
            }
        });
    });
}
/**
 * Returns existing access token.
 */
function getTokenProviderForExistingToken(_a) {
    var configuration = _a.configuration;
    return __awaiter(this, void 0, void 0, function () {
        var tokenProvider, currentToken;
        return __generator(this, function (_b) {
            switch (_b.label) {
                case 0:
                    core.Logger.debug('Generating token provider for token from the cookie');
                    tokenProvider = createSdkHelpers(configuration, TokenType.ExistingAccessToken).tokenProvider;
                    configuration.auth.setTokenProvider(tokenProvider);
                    return [4 /*yield*/, tokenProvider.getTokenInfo()];
                case 1:
                    currentToken = _b.sent();
                    core.Logger.debug('Successfully generated provider token from the cookie');
                    return [2 /*return*/, currentToken];
            }
        });
    });
}
/**
 * Returns access token for the anonymous session.
 */
function generateAnonymousAccessToken(_a) {
    var configuration = _a.configuration, apolloReq = _a.apolloReq;
    return __awaiter(this, void 0, void 0, function () {
        var tokenProvider, currentToken;
        return __generator(this, function (_b) {
            switch (_b.label) {
                case 0:
                    core.Logger.debug("Generating anonymous access token for operation \"" + apolloReq.operationName + "\"");
                    tokenProvider = createSdkHelpers(configuration, TokenType.AnonymousAccessToken).tokenProvider;
                    configuration.auth.setTokenProvider(tokenProvider);
                    return [4 /*yield*/, tokenProvider.getTokenInfo()];
                case 1:
                    currentToken = _b.sent();
                    core.Logger.debug("Successfully generated anonymous access token for operation \"" + apolloReq.operationName + "\"");
                    return [2 /*return*/, currentToken];
            }
        });
    });
}
/**
 * Returns access token for the logged in customer.
 */
function generateUserAccessToken(_a) {
    var apolloReq = _a.apolloReq, configuration = _a.configuration;
    return __awaiter(this, void 0, void 0, function () {
        var tokenProvider, currentToken;
        return __generator(this, function (_b) {
            switch (_b.label) {
                case 0:
                    core.Logger.debug("Generating user access token for operation \"" + apolloReq.operationName + "\"");
                    tokenProvider = createSdkHelpers(configuration, TokenType.UserAccessToken, apolloReq).tokenProvider;
                    configuration.auth.setTokenProvider(tokenProvider);
                    return [4 /*yield*/, tokenProvider.getTokenInfo()];
                case 1:
                    currentToken = _b.sent();
                    core.Logger.debug("Successfully generated user access token for operation \"" + apolloReq.operationName + "\"");
                    return [2 /*return*/, currentToken];
            }
        });
    });
}
/**
 * Handler for checking if it's necessary to generate a server or anonymous access token.
 */
function handleBeforeAuth(_a) {
    var _b;
    var configuration = _a.configuration, apolloReq = _a.apolloReq;
    return __awaiter(this, void 0, void 0, function () {
        var existingToken, isAnonymousRequestToken, isServer, customToken;
        return __generator(this, function (_c) {
            switch (_c.label) {
                case 0:
                    existingToken = configuration.auth.onTokenRead();
                    isAnonymousRequestToken = !isAnonymousSession(existingToken) && !isUserSession(existingToken) && isAnonymousOperation(apolloReq.operationName);
                    isServer = isServerOperation(configuration, apolloReq.operationName);
                    return [4 /*yield*/, ((_b = configuration.customToken) === null || _b === void 0 ? void 0 : _b.call(configuration, {
                            configuration: configuration,
                            isServer: isServer,
                            apolloReq: apolloReq
                        }))];
                case 1:
                    customToken = _c.sent();
                    if (customToken) {
                        return [2 /*return*/, customToken];
                    }
                    if (!isServer) return [3 /*break*/, 3];
                    return [4 /*yield*/, getServerAccessToken({
                            configuration: configuration,
                            apolloReq: apolloReq
                        })];
                case 2: return [2 /*return*/, _c.sent()];
                case 3:
                    if (!(existingToken && !isAnonymousRequestToken)) return [3 /*break*/, 5];
                    return [4 /*yield*/, getTokenProviderForExistingToken({
                            configuration: configuration
                        })];
                case 4: return [2 /*return*/, _c.sent()];
                case 5:
                    if (!isAnonymousRequestToken) return [3 /*break*/, 7];
                    return [4 /*yield*/, generateAnonymousAccessToken({
                            configuration: configuration,
                            apolloReq: apolloReq
                        })];
                case 6: return [2 /*return*/, _c.sent()];
                case 7: return [4 /*yield*/, getGuestAccessToken({
                        configuration: configuration
                    })];
                case 8: return [2 /*return*/, _c.sent()];
            }
        });
    });
}
/**
 * The handler that generates an access token for the user if all three conditions are met:
 *  - the customer is not already logged in;
 *  - the customer performed one of the user-specific operations;
 *  - response from the commercetools doesn't contain any errors, meaning that the given credentials are valid;
 */
function handleAfterAuth(_a) {
    var _b;
    var apolloReq = _a.apolloReq, response = _a.response, configuration = _a.configuration;
    return __awaiter(this, void 0, void 0, function () {
        var tokenProvider, currentToken;
        return __generator(this, function (_c) {
            tokenProvider = configuration.auth.getTokenProvider();
            if (!Object.keys(tokenProvider).length) {
                return [2 /*return*/];
            }
            currentToken = tokenProvider.getTokenInfo();
            if (!isUserSession(currentToken) && isUserOperation(apolloReq.operationName) && !((_b = response.errors) === null || _b === void 0 ? void 0 : _b.length)) {
                return [2 /*return*/, generateUserAccessToken({
                        apolloReq: apolloReq,
                        configuration: configuration
                    })];
            }
            return [2 /*return*/, currentToken];
        });
    });
}

/**
 * Creates handler for logging certain GraphQL and network errors.
 */
function createErrorHandler() {
    return apolloLinkError.onError(function (_a) {
        var graphQLErrors = _a.graphQLErrors, networkError = _a.networkError;
        if (graphQLErrors) {
            graphQLErrors.map(function (_a) {
                var message = _a.message, locations = _a.locations, path = _a.path;
                if (!message.includes('Resource Owner Password Credentials Grant')) {
                    if (!locations) {
                        core.Logger.error("[GraphQL error]: Message: " + message + ", Path: " + path);
                        return;
                    }
                    var parsedLocations = locations.map(function (_a) {
                        var column = _a.column, line = _a.line;
                        return "[column: " + column + ", line: " + line + "]";
                    });
                    core.Logger.error("[GraphQL error]: Message: " + message + ", Location: " + parsedLocations.join(', ') + ", Path: " + path);
                }
            });
        }
        if (networkError) {
            core.Logger.error("[Network error]: " + networkError);
        }
    });
}
/**
 * Creates handler for retrying requests to the commercetools server if specific conditions are met.
 */
function createRetryHandler(_a) {
    var configuration = _a.configuration;
    return new apolloLinkRetry.RetryLink({
        attempts: function (count, operation, error) {
            var _a, _b;
            if (count > 3) {
                return false;
            }
            var customRetry = (_a = configuration.customRetry) === null || _a === void 0 ? void 0 : _a.call(configuration, {
                count: count,
                operation: operation,
                error: error
            });
            if (customRetry) {
                return true;
            }
            var tokenProvider = configuration.auth.getTokenProvider();
            if (((_b = error === null || error === void 0 ? void 0 : error.result) === null || _b === void 0 ? void 0 : _b.message) === 'invalid_token') {
                core.Logger.debug("Apollo retry-link, the operation (" + operation.operationName + ") sent with wrong token, creating a new one... (attempt: " + count + ")");
                tokenProvider.invalidateTokenInfo();
                return true;
            }
            return false;
        },
        delay: function () { return 0; }
    });
}
/**
 * Creates ApolloLink for Apollo GraphQL client.
 */
function createLinks(configuration) {
    var _this = this;
    var tokenLink = apolloLinkContext.setContext(function (apolloReq, _a) {
        var headers = _a.headers;
        return __awaiter(_this, void 0, void 0, function () {
            var currentToken;
            return __generator(this, function (_b) {
                switch (_b.label) {
                    case 0:
                        core.Logger.debug('Apollo authLinkBefore', apolloReq.operationName);
                        return [4 /*yield*/, handleBeforeAuth({
                                configuration: configuration,
                                apolloReq: apolloReq
                            })];
                    case 1:
                        currentToken = _b.sent();
                        return [2 /*return*/, {
                                headers: __assign(__assign({}, headers), { authorization: "Bearer " + currentToken.access_token })
                            }];
                }
            });
        });
    });
    var authLink = new apolloLink.ApolloLink(function (apolloReq, forward) {
        return utilities.asyncMap(forward(apolloReq), function (response) { return __awaiter(_this, void 0, void 0, function () {
            var errors;
            return __generator(this, function (_a) {
                switch (_a.label) {
                    case 0:
                        core.Logger.debug('Apollo authLinkAfter', apolloReq.operationName);
                        return [4 /*yield*/, handleAfterAuth({
                                apolloReq: apolloReq,
                                response: response,
                                configuration: configuration
                            })];
                    case 1:
                        _a.sent();
                        errors = (response.errors || []).filter(function (_a) {
                            var message = _a.message;
                            return !message.includes('Resource Owner Password Credentials Grant') &&
                                !message.includes('This endpoint requires an access token issued either');
                        });
                        return [2 /*return*/, __assign(__assign({}, response), { errors: errors })];
                }
            });
        }); });
    });
    var httpLink = apolloLinkHttp.createHttpLink({
        uri: configuration.api.uri,
        fetch: fetch
    });
    return apolloLink.ApolloLink.from([
        createErrorHandler(),
        createRetryHandler({ configuration: configuration }),
        tokenLink,
        authLink.concat(httpLink)
    ]);
}

/**
 * Creates new Apollo GraphQL client.
 */
function createApolloClient(configuration) {
    var clientConfiguration = __assign({ cache: new apolloCacheInmemory.InMemoryCache() }, configuration.customOptions);
    if (!clientConfiguration.link) {
        clientConfiguration.link = createLinks(configuration);
    }
    return new ApolloClient__default["default"](clientConfiguration);
}

/**
 * Merges integration configuration with defaults and creates GraphQL client.
 */
function onCreate(projectSettings) {
    var languageMap = projectSettings.languageMap || {};
    var acceptLanguage = projectSettings.acceptLanguage || defaultSettings.acceptLanguage;
    var locale = projectSettings.locale || defaultSettings.locale;
    var config = __assign(__assign(__assign({}, defaultSettings), projectSettings), { languageMap: languageMap, acceptLanguage: languageMap[locale] || acceptLanguage, auth: projectSettings.auth || defaultSettings.auth });
    return {
        config: config,
        client: config.client || createApolloClient(config)
    };
}
var createApiClient = core.apiClientFactory({
    onCreate: onCreate,
    api: api,
    extensions: getExtensions()
}).createApiClient;

exports.api = api;
exports.createApiClient = createApiClient;
//# sourceMappingURL=index.js.map
